@@ -8,7 +8,7 @@ package IO::Async::Loop::Poll;
 use strict;
 use warnings;
 
-our $VERSION = '0.69';
+our $VERSION = '0.71';
 use constant API_VERSION => '0.49';
 
 use base qw( IO::Async::Loop );
@@ -182,7 +182,7 @@ sub post_poll
       }
    }
 
-   # Since we have no way to know if the timeout occured, we'll have to
+   # Since we have no way to know if the timeout occurred, we'll have to
    # attempt to fire any waiting timeout events anyway
    $count += $self->_manage_queues;
 
@@ -231,9 +231,9 @@ sub loop_once
 
          if( ( $pollret == -1 and $! == EINTR ) or $pollret == 0 
                  and defined $self->{sigproxy} ) {
-            # A signal occured and we have a sigproxy. Allow one more poll call
-            # with zero timeout. If it finds something, keep that result. If it
-            # finds nothing, keep -1
+            # A signal occurred and we have a sigproxy. Allow one more poll
+            # call with zero timeout. If it finds something, keep that result.
+            # If it finds nothing, keep -1
 
             # Preserve $! whatever happens
             local $!;
@@ -251,17 +251,26 @@ sub loop_once
       return $self->post_poll;
    }
    else {
-      my $msec = defined $timeout ? $timeout * 1000 : -1;
       my @pollmasks = %{ $self->{pollmask} };
 
-      my $pollret = IO::Poll::_poll( $msec, @pollmasks );
-      if( $pollret == -1 and $! == EINTR or
-          $pollret == 0 and $self->{sigproxy} ) {
-         local $!;
+      # Perl 5.8.x's IO::Poll::_poll gets confused with no masks
+      my $pollret;
+      if( @pollmasks ) {
+         my $msec = defined $timeout ? $timeout * 1000 : -1;
+         $pollret = IO::Poll::_poll( $msec, @pollmasks );
+         if( $pollret == -1 and $! == EINTR or
+             $pollret == 0 and $self->{sigproxy} ) {
+            local $!;
 
-         @pollmasks = %{ $self->{pollmask} };
-         my $secondattempt = IO::Poll::_poll( $msec, @pollmasks );
-         $pollret = $secondattempt if $secondattempt > 0;
+            @pollmasks = %{ $self->{pollmask} };
+            my $secondattempt = IO::Poll::_poll( $msec, @pollmasks );
+            $pollret = $secondattempt if $secondattempt > 0;
+         }
+
+      }
+      else {
+         # Workaround - we'll use select to fake a millisecond-accurate sleep
+         $pollret = select( undef, undef, undef, $timeout );
       }
 
       return undef unless defined $pollret;
