@@ -7,10 +7,9 @@ package IO::Async::Resolver;
 
 use strict;
 use warnings;
-use 5.010;
 use base qw( IO::Async::Function );
 
-our $VERSION = '0.69';
+our $VERSION = '0.71';
 
 # Socket 2.006 fails to getaddrinfo() AI_NUMERICHOST properly on MSWin32
 use Socket 2.007 qw(
@@ -114,6 +113,34 @@ sub _init
    $started = 1;
 }
 
+sub debug_printf_call
+{
+   my $self = shift;
+   my ( $type, undef, @data ) = @_;
+
+   my $arg0;
+   if( $type eq "getaddrinfo" ) {
+      my %args = @data;
+      $arg0 = sprintf "%s:%s", @args{qw( host service )};
+   }
+   elsif( $type eq "getnameinfo" ) {
+      # cheat
+      $arg0 = sprintf "%s:%s", ( Socket::getnameinfo( $data[0], NI_NUMERICHOST|NI_NUMERICSERV ) )[1,2];
+   }
+   else {
+      $arg0 = $data[0];
+   }
+
+   $self->debug_printf( "CALL $type $arg0" );
+}
+
+sub debug_printf_result
+{
+   my $self = shift;
+   my ( @result ) = @_;
+   $self->debug_printf( "RESULT n=" . scalar @result );
+}
+
 =head1 METHODS
 
 The following methods documented with a trailing call to C<< ->get >> return
@@ -324,7 +351,7 @@ sub getaddrinfo
       croak "Expected 'on_error' or to return a Future";
 
    my $host    = $args{host}    || "";
-   my $service = $args{service} // "";
+   my $service = $args{service}; defined $service or $service = "";
    my $flags   = $args{flags}   || 0;
 
    $flags |= AI_PASSIVE if $args{passive};
